%define pkg       squid
%define ver       3.1.14
%define maj       %(echo %{ver} | cut -d'.' -f1)
%define min       %(echo %{ver} | cut -d'.' -f2)
%define pkgid     %{maj}
%define pkgstr    %{pkg}%{pkgid}

%define sel_modn  selinux-policy-addon
%define sel_modv  0.2.3


Summary:          The Squid proxy caching server
Name:             %{pkgstr}
Version:          %{ver}
Release:          1%{?dist}%{?pext}
License:          GPL
Group:            System Environment/Daemons
Source0:          http://www.squid-cache.org/Versions/v%{maj}/%{maj}.%{min}/%{pkg}-%{ver}.tar.bz2
Source1:          %{pkg}.init
Source2:          %{pkg}.logrotate
Source3:          %{pkg}.sysconfig
Source4:          %{pkg}.conf
Source5:          %{pkg}.pam
Patch0:           %{pkg}-3.1.14-paths.patch
Patch1:           %{pkg}-3.0.13-config.patch
URL:              http://www.squid-cache.org/
Buildroot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:           The Squid Project <squid-bugs@squid-cache.org>
Requires(pre):    /usr/sbin/groupadd /usr/sbin/useradd
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/chkconfig /sbin/service
Requires(postun): /sbin/service
BuildRequires:    cyrus-sasl-devel db4-devel krb5-devel
BuildRequires:    libcap-devel openldap-devel openssl-devel
BuildRequires:    pam-devel pkgconfig

%description
Squid is a high-performance proxy caching server for Web clients, supporting
FTP, Gopher and HTTP data objects. Unlike traditional caching software, Squid
handles all requests in a single, non-blocking, I/O-driven process. It keeps
metadata and especially hot objects cached in RAM, caches DNS lookups, supports
non-blocking DNS lookups, and implements negative caching of failed requests.


%package          selinux
Summary:          SELinux support for Squid
Group:            System Environment/Base
Requires:         %{name} = %{version}-%{release}
Requires:         %{sel_modn} >= %{sel_modv}
Requires(post):   /sbin/restorecon %{_sbindir}/selinuxenabled /sbin/fixfiles

%description      selinux
This package enables Squid to work with SELinux.


%prep
%setup -q -n %{pkg}-%{ver}
%patch0 -p1
%patch1 -p1

# Fix path to Perl
for FILE in `find . -type f -name "*.pl" -exec fgrep -l "/bin/perl" {} \;`; do
  %{__perl} -i -pe 's+(/.*)?/bin/perl+%{__perl}+g' ${FILE}
done

# Prepare docs
%{__mkdir_p} doc/helpers/basic/{DB,LDAP,MSNT,SASL,SMB,multi,radius}
%{__mkdir_p} doc/helpers/external/{ip_user,ldap_group,unix_group}
%{__mkdir_p} doc/helpers/negotiate/kerberos
%{__mkdir_p} doc/helpers/ntlm/no_check

%{__cp} helpers/basic_auth/DB/passwd.sql  doc/helpers/basic/DB
%{__cp} helpers/basic_auth/LDAP/README    doc/helpers/basic/LDAP
%{__cp} helpers/basic_auth/MSNT/COPYING*  doc/helpers/basic/MSNT
%{__cp} helpers/basic_auth/MSNT/README*   doc/helpers/basic/MSNT
%{__cp} helpers/basic_auth/SASL/README    doc/helpers/basic/SASL
%{__cp} helpers/basic_auth/SASL/*.conf    doc/helpers/basic/SASL
%{__cp} helpers/basic_auth/SMB/COPYING*   doc/helpers/basic/SMB
%{__cp} helpers/basic_auth/SMB/ChangeLog  doc/helpers/basic/SMB
%{__cp} helpers/basic_auth/SMB/README     doc/helpers/basic/SMB
%{__cp} helpers/basic_auth/mult*/README*  doc/helpers/basic/multi
%{__cp} helpers/basic_auth/squid*/README  doc/helpers/basic/radius

%{__cp} helpers/external*/ip_user/README  doc/helpers/external/ip_user
%{__cp} helpers/external*/ip_user/license doc/helpers/external/ip_user
%{__cp} helpers/external*/ip_user/*.conf  doc/helpers/external/ip_user
%{__cp} helpers/external*/ldap*/ChangeLog doc/helpers/external/ldap_group
%{__cp} helpers/external*/ldap*/README    doc/helpers/external/ldap_group
%{__cp} helpers/external*/unix*/README    doc/helpers/external/unix_group

%{__cp} helpers/negotiat*/squid*/COPYING  doc/helpers/negotiate/kerberos
%{__cp} helpers/negotiat*/squid*/README   doc/helpers/negotiate/kerberos

%{__cp} helpers/ntlm*/no_check/README*    doc/helpers/ntlm/no_check/README


%build
%configure \
	CPPFLAGS="${CPPFLAGS} -DOPENSSL_NO_KRB5"                \
	--sysconfdir=%{_sysconfdir}/%{pkg}                      \
	--libexecdir=%{_libexecdir}/%{pkg}                      \
	--datadir=%{_datadir}/%{pkg}                            \
	--enable-async-io=64                                    \
	--enable-storeio="aufs,diskd,ufs"                       \
	--enable-disk-io="AIO,Blocking,DiskDaemon,DiskThreads"  \
	--enable-removal-policies="heap,lru"                    \
	--enable-icmp                                           \
	--enable-delay-pools                                    \
	--enable-icap-client                                    \
	--enable-useragent-log                                  \
	--enable-referer-log                                    \
	--enable-kill-parent-hack                               \
	--enable-arp-acl                                        \
	--enable-ssl                                            \
	--enable-forw-via-db                                    \
	--enable-cache-digests                                  \
	--enable-epoll                                          \
	--enable-linux-netfilter                                \
	--enable-follow-x-forwarded-for                         \
	--disable-ident-lookups                                 \
	--enable-auth="basic,digest,negotiate,ntlm"             \
	--enable-basic-auth-helpers="DB,LDAP,MSNT,NCSA,PAM,SASL,SMB,getpwnam,multi-domain-NTLM,squid_radius_auth" \
	--enable-ntlm-auth-helpers="fakeauth,no_check,smb_lm"   \
	--enable-ntlm-fail-open                                 \
	--enable-digest-auth-helpers="eDirectory,ldap,password" \
	--enable-negotiate-auth-helpers="squid_kerb_auth"       \
	--enable-external-acl-helpers="ip_user,ldap_group,session,unix_group,wbinfo_group" \
	--enable-stacktraces                                    \
	--enable-x-accelerator-vary                             \
	--enable-zph-qos                                        \
	--with-default-user=%{pkg}                              \
	--with-logdir=%{_localstatedir}/log/%{pkg}              \
	--with-pidfile=%{_localstatedir}/run/%{pkg}.pid         \
	--with-pthreads                                         \
	--with-aio                                              \
	--with-dl                                               \
	--with-openssl=%{_prefix}                               \
	--with-large-files                                      \
	--with-filedescriptors=32768

%{__make} #%{?_smp_mflags}


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_initrddir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sysconfdir}/{httpd/conf.d,logrotate.d,pam.d,sysconfig}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_prefix}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/{cache,log}/%{pkg}

%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	install

%{__install} -m 0755 %{SOURCE1} ${RPM_BUILD_ROOT}%{_initrddir}/%{pkg}
%{__install} -m 0644 %{SOURCE2} ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/%{pkg}
%{__install} -m 0644 %{SOURCE3} ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/%{pkg}

%{__install} -m 0644 %{SOURCE4} ${RPM_BUILD_ROOT}%{_sysconfdir}/httpd/conf.d
%{__install} -m 0644 %{SOURCE5} ${RPM_BUILD_ROOT}%{_sysconfdir}/pam.d/%{pkg}

%{__chmod}   u+s                ${RPM_BUILD_ROOT}%{_libexecdir}/%{pkg}/pinger

%{__rm}      -f                 ${RPM_BUILD_ROOT}%{_bindir}/Run{Accel,Cache}


%pre
if ! getent group  %{pkg} >/dev/null 2>&1; then
  /usr/sbin/groupadd -r -g 23 %{pkg}
fi
if ! getent passwd %{pkg} >/dev/null 2>&1; then
  /usr/sbin/useradd  -r -u 23 -g %{pkg}   \
	-d %{_localstatedir}/cache/%{pkg} \
	-c "SQUID Service user"           \
	-s /sbin/nologin %{pkg}
fi
exit 0			# Always pass


%post
/sbin/chkconfig --add %{pkg}

%post selinux
if /usr/sbin/selinuxenabled && [ -e /selinux/policyvers ]; then
  /sbin/fixfiles   -R %{name} restore
# /sbin/restorecon -R %{_localstatedir}/cache/%{pkg}
  /sbin/restorecon -R %{_localstatedir}/log/%{pkg}
fi


%preun
if [ $1 -eq 0 ]; then	# Remove
  /sbin/service %{pkg} stop >/dev/null 2>&1
  /sbin/chkconfig --del %{pkg}
fi


%postun
if [ $1 -ge 1 ]; then	# Upgrade
  /sbin/service %{pkg} condrestart >/dev/null 2>&1 || :
fi


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc CONTRIBUTORS COPY* CREDITS ChangeLog INSTALL QUICK*
%doc README RELEASENOTES* SPONSORS doc/*.txt doc/helpers
%{_initrddir}/%{pkg}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{pkg}
%config(noreplace) %{_sysconfdir}/sysconfig/%{pkg}
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{pkg}.conf
%config(noreplace) %{_sysconfdir}/pam.d/%{pkg}
%attr(750,root,%{pkg}) %dir %{_sysconfdir}/%{pkg}
%attr(640,root,%{pkg}) %config(noreplace) %{_sysconfdir}/%{pkg}/*.conf
%attr(640,root,%{pkg}) %config(noreplace) %{_sysconfdir}/%{pkg}/*.css
%{_sysconfdir}/%{pkg}/*.default
%{_sysconfdir}/%{pkg}/*.documented
%{_bindir}/squidclient
%{_libexecdir}/%{pkg}
%{_sbindir}/%{pkg}
%dir %{_datadir}/%{pkg}
%config(noreplace) %{_datadir}/%{pkg}/errors
%config(noreplace) %{_datadir}/%{pkg}/icons
%{_datadir}/%{pkg}/mib.txt
%{_mandir}/man1/*.1*
%{_mandir}/man8/*.8*
%attr(750,%{pkg},%{pkg}) %dir %{_localstatedir}/cache/%{pkg}
%attr(750,%{pkg},%{pkg}) %dir %{_localstatedir}/log/%{pkg}

%files selinux
%defattr(-,root,root)


%changelog
* Mon Jul 11 2011 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.14-1
- New version (3.1.14)

* Fri Apr 08 2011 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.12-1
- New version (3.1.12)

* Wed Feb 09 2011 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.11-1
- Do not forcefully disable HTTP violations (George Nikandrov)
- New version (3.1.11)

* Tue Jan 18 2011 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.10-1
- New version (3.1.10)

* Tue Nov 02 2010 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.9-1
- New version (3.1.9)

* Sat Sep 11 2010 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.8-1
- New version (3.1.8)

* Thu Aug 05 2010 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.6-1
- New version (3.1.6)

* Mon May 31 2010 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.4-1
- New version (3.1.4)

* Mon May 17 2010 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.3-1
- New version (3.1.3)

* Mon Apr 12 2010 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.1-1
- New version (3.1.1)

* Thu Mar 18 2010 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.18-1
- New version (3.1.0.18)

* Thu Feb 25 2010 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.17-1
- New version (3.1.0.17)

* Tue Feb 02 2010 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.16-1
- New version (3.1.0.16)

* Thu Nov 26 2009 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.15-1
- New version (3.1.0.15)

* Sun Sep 27 2009 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.14-1
- New version (3.1.0.14)

* Fri Aug 07 2009 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.13-1
- New version (3.1.0.13)

* Sat Jul 04 2009 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.9-2
- Fixed installation of error pages

* Sun Jun 28 2009 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.9-1
- New version (3.1.0.9)

* Fri May 29 2009 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.8-1
- New version (3.1.0.8)

* Thu Apr 09 2009 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.7-1
- New version (3.1.0.7)

* Sun Mar 15 2009 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.6-1
- New version (3.1.0.6)

* Tue Feb 17 2009 Peter Pramberger <peterpramb@member.fsf.org> - 3.1.0.5-1
- Initial build
